@@ -1,5 +1,7 @@
+from abc import ABC
+from typing import Type
+
 from django.contrib.auth import get_user_model
-from strawberry.field import StrawberryField
 from strawberry.types import Info
 
 import gqlauth
@@ -9,32 +11,28 @@ from gqlauth.user.resolvers import BaseMixin
 UserModel = get_user_model()
 
 
-class ArgMixin:
-    field: StrawberryField
-
-    def __init_subclass__(cls: BaseMixin, **kwargs):
+class ArgMixin(BaseMixin, ABC):
+    def __init_subclass__(cls: Type[BaseMixin], **kwargs):
         input_type = cls.resolve_mutation.__annotations__["input_"]
         return_type = cls.resolve_mutation.__annotations__["return"]
 
         @gqlauth.core.field_.field(description=cls.__doc__, directives=cls.directives)
         @inject_arguments(input_type.__annotations__)
         @hide_args_kwargs
-        def field(info: Info, **kwargs) -> return_type:
-            return cls.resolve_mutation(info, input_type(**kwargs))
+        def field(info: Info, **kwargs) -> return_type:  # type: ignore
+            return cls.resolve_mutation(info, input_type(**kwargs))  # type: ignore
 
-        cls.field = field
+        cls.field = field  # type: ignore
 
 
-class RelayMixin:
-    field: StrawberryField
-
-    def __init_subclass__(cls: BaseMixin, **kwargs):
+class RelayMixin(BaseMixin, ABC):
+    def __init_subclass__(cls: Type[BaseMixin], **kwargs):
         input_type = cls.resolve_mutation.__annotations__["input_"]
         return_type = cls.resolve_mutation.__annotations__["return"]
 
         @gqlauth.core.field_.field(description=cls.__doc__, directives=cls.directives)
         @hide_args_kwargs
-        def field(info: Info, input: input_type) -> return_type:
-            return cls.resolve_mutation(info, input)
+        def field(info: Info, input: input_type) -> return_type:  # type: ignore
+            return cls.resolve_mutation(info, input)  # type: ignore
 
-        cls.field = field
+        cls.field = field  # type: ignore
